@@ -1,10 +1,12 @@
-from datetime import datetime
 import json
+from datetime import datetime
 from os import environ
 from pathlib import Path
-from typing import Any, Optional, Union
+from typing import Any, Dict, List, Optional, OrderedDict, Union
+
+import dotenv
+
 
-__version__ = "4.0.1"
 __all__ = [
     "get",
     "get_bool",
@@ -17,9 +19,31 @@ __all__ = [
 ]
 
 
-# Allow a developer-defined Docker secrets path,
+# Allow a developer-defined sys vars path,
 # defaulting to the Docker secrets Linux path
-__SECRETS_PATH = Path(environ.get("SYS_VARS_PATH", "/run/secrets")).resolve()
+__SYS_VARS_PATH = Path(environ.get("SYS_VARS_PATH", "/run/secrets")).resolve()
+
+# Load the contents of a .env file.
+# It's OK if it doesn't exist
+__DOT_ENV_CONTENT: OrderedDict = dotenv.dotenv_values(__SYS_VARS_PATH / ".env")
+
+
+def __from_directory(key: str) -> Optional[str]:
+    """Try to find the variable in a directory."""
+    try:
+        return (__SYS_VARS_PATH / key).read_text().strip() or None
+    except FileNotFoundError:
+        return None
+
+
+def __from_env(key: str) -> Optional[str]:
+    """Try to get the variable from the enviornment."""
+    return environ.get(key)
+
+
+def __from_env_file(key) -> Optional[str]:
+    """Try to get the variable from a .env file."""
+    return __DOT_ENV_CONTENT.get(key)
 
 
 class SysVarNotFoundError(Exception):
@@ -34,8 +58,8 @@ class SysVarNotFoundError(Exception):
 def get(key: str, *, default: Optional[Any] = None) -> str:
     """Get a system variable value as a str type.
 
-    Check Docker secrets and os.environ for the key,
-    preferring values from Docker secrets. If the key
+    Check the value of SYS_VARS_PATH and os.environ for the key,
+    preferring values from SYS_VARS_PATH. If the key
     is not found and a default value is specified,
     the default value will be returned. Otherwise,
     SysVarNotFoundError will be raised.
@@ -44,30 +68,26 @@ def get(key: str, *, default: Optional[Any] = None) -> str:
     @param default - A default value is the key is not found.
     @return - The system variable value.
     """
-    try:
-        # Try to get a Docker secret value
-        path = __SECRETS_PATH / key
-        sys_var_value = path.read_text().strip() or None
+    # First check a directory, falling back to the environment
+    var_value = __from_directory(key)
+    if var_value is None:
+        var_value = __from_env(key)
+    if var_value is None:
+        var_value = __from_env_file(key)
 
-    # The secret does not exist
-    except FileNotFoundError:
-        # Try to get it from the environment
-        sys_var_value = environ.get(key)
+    # We have a value, send it back
+    if var_value is not None:
+        return var_value.strip()
 
-    # The sys variable could not be loaded at all
-    if sys_var_value is None:
-        # A default value was specified, return it
-        if default is not None:
-            return default
+    # We counldn't find the variable anywhere, try to send back a default value
+    if default is not None:
+        return default
 
-        # No default value was given, raise an exception
-        raise SysVarNotFoundError(f'Could not get value for system variable "{key}"')
-
-    # A value for the key was found!
-    return sys_var_value
+    # No default value was given, so raise an exception
+    raise SysVarNotFoundError(f'Could not get value for system variable "{key}"')
 
 
-def get_bool(key: str, **kwargs: dict) -> bool:
+def get_bool(key: str, **kwargs: Dict[str, Any]) -> bool:
     """Get a system variable as a bool object.
 
     See signature of get() for parameter details."""
@@ -92,7 +112,7 @@ def get_bool(key: str, **kwargs: dict) -> bool:
         return bool(sys_val)
 
 
-def get_datetime(key: str, **kwargs: dict) -> datetime:
+def get_datetime(key: str, **kwargs: Dict[str, Any]) -> datetime:
     """Get a system variable as a datetime.datetime object.
 
     The datestring is parsed using datetime.datetime.fromisoformat(),
@@ -111,7 +131,7 @@ def get_datetime(key: str, **kwargs: dict) -> datetime:
     return datetime.fromisoformat(sys_val)
 
 
-def get_float(key: str, **kwargs: dict) -> float:
+def get_float(key: str, **kwargs: Dict[str, Any]) -> float:
     """Get a system variable as a float value.
 
     Raises ValueError if the data cannot be cast.
@@ -120,7 +140,7 @@ def get_float(key: str, **kwargs: dict) -> float:
     return float(get(key, **kwargs))
 
 
-def get_int(key: str, **kwargs: dict) -> int:
+def get_int(key: str, **kwargs: Dict[str, Any]) -> int:
     """Get a system variable as an int value.
 
     Raises ValueError if the data cannot be cast.
@@ -129,7 +149,7 @@ def get_int(key: str, **kwargs: dict) -> int:
     return int(get(key, **kwargs))
 
 
-def get_json(key: str, **kwargs: dict) -> Union[dict, list]:
+def get_json(key: str, **kwargs: Dict[str, Any]) -> Union[Dict[str, Any], List[Any]]:
     """Get a JSON string system variable as a dictionary object.
 
     Unlike the other methods whose names suggest the return data type
@@ -152,7 +172,7 @@ def get_json(key: str, **kwargs: dict) -> Union[dict, list]:
     return json.loads(sys_val)
 
 
-def get_path(key: str, **kwargs: dict) -> Path:
+def get_path(key: str, **kwargs: Dict[str, Any]) -> Path:
     """Get a file path string system variable as a pathlib.Path instance.
 
     See signature of get() for parameter details."""
